@@ -5,9 +5,12 @@ import vkontakte
 import time
 import logging
 
+__all__ = ['api_call']
+
 log = logging.getLogger('vkontakte_api')
 
 TIMEOUT = getattr(settings, 'VKONTAKTE_ADS_REQUEST_TIMEOUT', 1)
+ACCESS_TOKEN = getattr(settings, 'VKONTAKTE_API_ACCESS_TOKEN', None)
 
 VkontakteError = vkontakte.VKError
 
@@ -27,12 +30,15 @@ def get_api():
     '''
     Return API instance with latest token from database
     '''
-    tokens = get_tokens()
-    if not tokens:
-        update_token()
+    if ACCESS_TOKEN:
+        token = ACCESS_TOKEN
+    else:
         tokens = get_tokens()
-    t = tokens[0]
-    return vkontakte.API(token=t.access_token)
+        if not tokens:
+            update_token()
+            tokens = get_tokens()
+        token = tokens[0].access_token
+    return vkontakte.API(token=token)
 
 def api_call(method, **kwargs):
     '''
@@ -47,6 +53,10 @@ def api_call(method, **kwargs):
             update_token()
             vk = get_api()
             response = vk.get(method, timeout=TIMEOUT, **kwargs)
+        elif e.code == 6:
+            log.warning("Vkontakte error: '%s'" % (e.description))
+            time.sleep(10)
+            response = api_call(method, **kwargs)
         elif e.code == 9:
             log.warning("Vkontakte flood control registered while executing method %s with params %s" % (method, kwargs))
             time.sleep(1)
